@@ -11,10 +11,10 @@ class TgLogsMiddleware:
     def __call__(self, request):
 
         response = self.get_response(request)
-        if 400 >= response.status <= 500:
+        if 400 >= response.status_code <= 500:
             self.bot.send_message(
                 chat_id=os.getenv('chat_id'),
-                text=f'Status code: {response.status}\nBody: {response.body}',
+                text=f'Status code: {response.status_code}\nBody: {response.body}',
                 disable_web_page_preview=True
             )
 
